@@ -774,6 +774,10 @@ class CommandDispatcher:
         Args:
             count: How many tabs to switch back.
         """
+        if self._count() == 0:
+            # Running :tab-prev after last tab was closed
+            # See https://github.com/The-Compiler/qutebrowser/issues/1448
+            return
         newidx = self._current_index() - count
         if newidx >= 0:
             self._set_current_index(newidx)
@@ -790,6 +794,10 @@ class CommandDispatcher:
         Args:
             count: How many tabs to switch forward.
         """
+        if self._count() == 0:
+            # Running :tab-next after last tab was closed
+            # See https://github.com/The-Compiler/qutebrowser/issues/1448
+            return
         newidx = self._current_index() + count
         if newidx < self._count():
             self._set_current_index(newidx)
