@@ -175,9 +175,6 @@ class TabCompletionModel(base.BaseCompletionModel):
         objreg.get("app").new_window.connect(self.on_new_window)
         self.rebuild()
 
-    # slot argument should be mainwindow.MainWindow but can't import
-    # that at module level because of import loops.
-    @pyqtSlot(object)
     def on_new_window(self, window):
         """Add hooks to new windows."""
         window.tabbed_browser.new_tab.connect(self.on_new_tab)
