@@ -79,8 +79,8 @@ def get_window(via_ipc, force_window=False, force_tab=False,
         if open_target not in ('tab-silent', 'tab-bg-silent'):
             window_to_raise = window
     if window_to_raise is not None:
-        window_to_raise.setWindowState(window.windowState() &
-                                       ~Qt.WindowMinimized | Qt.WindowActive)
+        window_to_raise.setWindowState(
+            window.windowState() & ~Qt.WindowMinimized | Qt.WindowActive)
         window_to_raise.raise_()
         window_to_raise.activateWindow()
         QApplication.instance().alert(window_to_raise)
@@ -187,6 +187,8 @@ class MainWindow(QWidget):
         #self.tabWidget.setCurrentIndex(0)
         #QtCore.QMetaObject.connectSlotsByName(MainWindow)
 
+        objreg.get("app").new_window.emit(self)
+
     def __repr__(self):
         return utils.get_repr(self)
 
@@ -417,9 +419,6 @@ class MainWindow(QWidget):
                                       window=self.win_id)
         download_count = download_manager.rowCount()
         quit_texts = []
-        # Close if set to never ask for confirmation
-        if 'never' in confirm_quit:
-            pass
         # Ask if multiple-tabs are open
         if 'multiple-tabs' in confirm_quit and tab_count > 1:
             quit_texts.append("{} {} open.".format(
