@@ -26,6 +26,7 @@ import html
 import getpass
 import fnmatch
 import traceback
+import datetime
 
 import pkg_resources
 from PyQt5.QtCore import pyqtSlot, Qt, QSize, qVersion
@@ -35,7 +36,7 @@ from PyQt5.QtWidgets import (QDialog, QLabel, QTextEdit, QPushButton,
 
 import qutebrowser
 from qutebrowser.utils import version, log, utils, objreg, qtutils
-from qutebrowser.misc import miscwidgets, autoupdate, msgbox
+from qutebrowser.misc import miscwidgets, autoupdate, msgbox, httpclient
 from qutebrowser.browser.network import pastebin
 from qutebrowser.config import config
 
@@ -95,12 +96,13 @@ def get_fatal_crash_dialog(debug, data):
 
 def _get_environment_vars():
     """Gather environment variables for the crash info."""
-    masks = ('DESKTOP_SESSION', 'DE', 'QT_*', 'PYTHON*', 'LC_*', 'LANG')
+    masks = ('DESKTOP_SESSION', 'DE', 'QT_*', 'PYTHON*', 'LC_*', 'LANG',
+             'XDG_*')
     info = []
     for key, value in os.environ.items():
         for m in masks:
             if fnmatch.fnmatch(key, m):
-                info.append('%s = %s' % (key, value))
+                info.append('{} = {}'.format(key, value))
     return '\n'.join(sorted(info))
 
 
@@ -139,7 +141,8 @@ class _CrashDialog(QDialog):
         self.setWindowTitle("Whoops!")
         self.resize(QSize(640, 600))
         self._vbox = QVBoxLayout(self)
-        self._paste_client = pastebin.PastebinClient(self)
+        http_client = httpclient.HTTPClient()
+        self._paste_client = pastebin.PastebinClient(http_client, self)
         self._pypi_client = autoupdate.PyPIVersionClient(self)
         self._init_text()
 
@@ -236,7 +239,9 @@ class _CrashDialog(QDialog):
         try:
             application = QApplication.instance()
             launch_time = application.launch_time.ctime()
-            self._crash_info.append(('Launch time', launch_time))
+            crash_time = datetime.datetime.now().ctime()
+            text = 'Launch: {}\nCrash: {}'.format(launch_time, crash_time)
+            self._crash_info.append(('Timestamps', text))
         except Exception:
             self._crash_info.append(("Launch time", traceback.format_exc()))
         try:
@@ -504,11 +509,23 @@ class FatalCrashDialog(_CrashDialog):
     def _init_text(self):
         super()._init_text()
         text = ("<b>qutebrowser was restarted after a fatal crash.</b><br/>"
-                "<br/>Note: Crash reports for fatal crashes sometimes don't "
+                "QTWEBENGINE_NOTE"
+                "<br/>Crash reports for fatal crashes sometimes don't "
                 "contain the information necessary to fix an issue. Please "
                 "follow the steps in <a href='https://github.com/The-Compiler/"
                 "qutebrowser/blob/master/doc/stacktrace.asciidoc'>"
                 "stacktrace.asciidoc</a> to submit a stacktrace.<br/>")
+
+        if datetime.datetime.now() < datetime.datetime(2016, 4, 23):
+            note = ("<br/>Fatal crashes like this are often caused by the "
+                    "current QtWebKit backend.<br/><b>I'm currently running a "
+                    "crowdfunding for the new QtWebEngine backend, based on "
+                    "Chromium:</b> <a href='http://igg.me/at/qutebrowser'>"
+                    "igg.me/at/qutebrowser</a><br/>")
+            text = text.replace('QTWEBENGINE_NOTE', note)
+        else:
+            text = text.replace('QTWEBENGINE_NOTE', '')
+
         self._lbl.setText(text)
 
     def _init_checkboxes(self):
