@@ -70,10 +70,13 @@ def get_argparser():
                         help="How URLs should be opened if there is already a "
                              "qutebrowser instance running.")
     parser.add_argument('--json-args', help=argparse.SUPPRESS)
+    parser.add_argument('--temp-basedir-restarted', help=argparse.SUPPRESS)
 
     debug = parser.add_argument_group('debug arguments')
     debug.add_argument('-l', '--loglevel', dest='loglevel',
-                       help="Set loglevel", default='info')
+                       help="Set loglevel", default='info',
+                       choices=['critical', 'error', 'warning', 'info',
+                                'debug', 'vdebug'])
     debug.add_argument('--logfilter',
                        help="Comma-separated list of things to be logged "
                        "to the debug log on stdout.")
@@ -129,7 +132,6 @@ def get_argparser():
 
 
 def main():
-    """Main entry point for qutebrowser."""
     parser = get_argparser()
     if sys.platform == 'darwin' and getattr(sys, 'frozen', False):
         # Ignore Mac OS X' idiotic -psn_* argument...
