@@ -74,11 +74,13 @@ def _parse_search_term(s):
             term = s
         else:
             term = split[1]
+    elif not split:
+        raise ValueError("Empty search term!")
     else:
         engine = None
         term = s
 
-    log.url.debug("engine {}, term '{}'".format(engine, term))
+    log.url.debug("engine {}, term {!r}".format(engine, term))
     return (engine, term)
 
 
@@ -91,7 +93,7 @@ def _get_search_url(txt):
     Return:
         The search URL as a QUrl.
     """
-    log.url.debug("Finding search engine for '{}'".format(txt))
+    log.url.debug("Finding search engine for {!r}".format(txt))
     engine, term = _parse_search_term(txt)
     assert term
     if engine is None:
@@ -168,24 +170,13 @@ def fuzzy_url(urlstr, cwd=None, relative=False, do_search=True):
     Return:
         A target QUrl to a search page or the original URL.
     """
-    expanded = os.path.expanduser(urlstr)
-    if os.path.isabs(expanded):
-        path = expanded
-    elif relative and cwd:
-        path = os.path.join(cwd, expanded)
-    elif relative:
-        try:
-            path = os.path.abspath(expanded)
-        except OSError:
-            path = None
-    else:
-        path = None
+    urlstr = urlstr.strip()
+    path = get_path_if_valid(urlstr, cwd=cwd, relative=relative,
+                             check_exists=True)
 
-    stripped = urlstr.strip()
-    if path is not None and os.path.exists(path):
-        log.url.debug("URL is a local file")
+    if path is not None:
         url = QUrl.fromLocalFile(path)
-    elif (not do_search) or is_url(stripped):
+    elif (not do_search) or is_url(urlstr):
         # probably an address
         log.url.debug("URL is a fuzzy address")
         url = qurl_from_user_input(urlstr)
@@ -194,10 +185,10 @@ def fuzzy_url(urlstr, cwd=None, relative=False, do_search=True):
         try:
             url = _get_search_url(urlstr)
         except ValueError:  # invalid search engine
-            url = qurl_from_user_input(stripped)
-    log.url.debug("Converting fuzzy term {} to URL -> {}".format(
+            url = qurl_from_user_input(urlstr)
+    log.url.debug("Converting fuzzy term {!r} to URL -> {}".format(
                   urlstr, url.toDisplayString()))
-    if do_search and config.get('general', 'auto-search'):
+    if do_search and config.get('general', 'auto-search') and urlstr:
         qtutils.ensure_valid(url)
     else:
         if not url.isValid():
@@ -215,9 +206,9 @@ def _has_explicit_scheme(url):
     # after the scheme delimiter. Since we don't know of any URIs
     # using this and want to support e.g. searching for scoped C++
     # symbols, we treat this as not an URI anyways.
-    return (url.isValid() and url.scheme()
-            and not url.path().startswith(' ')
-            and not url.path().startswith(':'))
+    return (url.isValid() and url.scheme() and
+            not url.path().startswith(' ') and
+            not url.path().startswith(':'))
 
 
 def is_special_url(url):
@@ -243,7 +234,7 @@ def is_url(urlstr):
     """
     autosearch = config.get('general', 'auto-search')
 
-    log.url.debug("Checking if '{}' is a URL (autosearch={}).".format(
+    log.url.debug("Checking if {!r} is a URL (autosearch={}).".format(
                   urlstr, autosearch))
 
     urlstr = urlstr.strip()
@@ -253,8 +244,12 @@ def is_url(urlstr):
     if not autosearch:
         # no autosearch, so everything is a URL unless it has an explicit
         # search engine.
-        engine, _term = _parse_search_term(urlstr)
-        return engine is None
+        try:
+            engine, _term = _parse_search_term(urlstr)
+        except ValueError:
+            return False
+        else:
+            return engine is None
 
     if not qurl_userinput.isValid():
         # This will also catch URLs containing spaces.
@@ -342,6 +337,44 @@ def raise_cmdexc_if_invalid(url):
         raise cmdexc.CommandError(get_errstring(url))
 
 
+def get_path_if_valid(pathstr, cwd=None, relative=False, check_exists=False):
+    """Check if path is a valid path.
+
+    Args:
+        pathstr: The path as string.
+        cwd: The current working directory, or None.
+        relative: Whether to resolve relative files.
+        check_exists: Whether to check if the file
+                      actually exists of filesystem.
+
+    Return:
+        The path if it is a valid path, None otherwise.
+    """
+    pathstr = pathstr.strip()
+    log.url.debug("Checking if {!r} is a path".format(pathstr))
+    expanded = os.path.expanduser(pathstr)
+
+    if os.path.isabs(expanded):
+        path = expanded
+    elif relative and cwd:
+        path = os.path.join(cwd, expanded)
+    elif relative:
+        try:
+            path = os.path.abspath(expanded)
+        except OSError:
+            path = None
+    else:
+        path = None
+
+    if check_exists:
+        if path is not None and os.path.exists(path):
+            log.url.debug("URL is a local file")
+        else:
+            path = None
+
+    return path
+
+
 def filename_from_url(url):
     """Get a suitable filename from an URL.
 
@@ -462,6 +495,28 @@ class IncDecError(Exception):
         return '{}: {}'.format(self.msg, self.url.toString())
 
 
+def _get_incdec_value(match, incdec, url):
+    """Get a incremented/decremented URL based on a URL match."""
+    pre, zeroes, number, post = match.groups()
+    # This should always succeed because we match \d+
+    val = int(number)
+    if incdec == 'decrement':
+        if val <= 0:
+            raise IncDecError("Can't decrement {}!".format(val), url)
+        val -= 1
+    elif incdec == 'increment':
+        val += 1
+    else:
+        raise ValueError("Invalid value {} for indec!".format(incdec))
+    if zeroes:
+        if len(number) < len(str(val)):
+            zeroes = zeroes[1:]
+        elif len(number) > len(str(val)):
+            zeroes += '0'
+
+    return ''.join([pre, zeroes, str(val), post])
+
+
 def incdec_number(url, incdec, segments=None):
     """Find a number in the url and increment or decrement it.
 
@@ -503,23 +558,11 @@ def incdec_number(url, incdec, segments=None):
             continue
 
         # Get the last number in a string
-        match = re.match(r'(.*\D|^)(\d+)(.*)', getter())
+        match = re.match(r'(.*\D|^)(0*)(\d+)(.*)', getter())
         if not match:
             continue
 
-        pre, number, post = match.groups()
-        # This should always succeed because we match \d+
-        val = int(number)
-        if incdec == 'decrement':
-            if val <= 0:
-                raise IncDecError("Can't decrement {}!".format(val), url)
-            val -= 1
-        elif incdec == 'increment':
-            val += 1
-        else:
-            raise ValueError("Invalid value {} for indec!".format(incdec))
-        new_value = ''.join([pre, str(val), post])
-        setter(new_value)
+        setter(_get_incdec_value(match, incdec, url))
         return url
 
     raise IncDecError("No number found in URL!", url)
